summaryrefslogtreecommitdiffstats
path: root/opengl/java
diff options
context:
space:
mode:
authorSiva Velusamy <vsiva@google.com>2012-12-14 17:09:06 -0800
committerSiva Velusamy <vsiva@google.com>2012-12-19 16:31:56 -0800
commit0c1761bd37815c3776608a19c8e11d862b3e910c (patch)
tree79ba5b10c39459913dad480243e0211b63ed41b0 /opengl/java
parent0490f02eb72adcfd652f5e8373bf0a6c99592d54 (diff)
downloadframeworks_base-0c1761bd37815c3776608a19c8e11d862b3e910c.zip
frameworks_base-0c1761bd37815c3776608a19c8e11d862b3e910c.tar.gz
frameworks_base-0c1761bd37815c3776608a19c8e11d862b3e910c.tar.bz2
DdmServer: add controls for OpenGL tracing
Add a new JDWP packet to allow control of OpenGL tracing. Change-Id: Ic89e2f6299238a612df2f914581049f2cbba088c
Diffstat (limited to 'opengl/java')
-rw-r--r--opengl/java/android/opengl/GLUtils.java7
1 files changed, 2 insertions, 5 deletions
diff --git a/opengl/java/android/opengl/GLUtils.java b/opengl/java/android/opengl/GLUtils.java
index 1527f22..a9d33dd 100644
--- a/opengl/java/android/opengl/GLUtils.java
+++ b/opengl/java/android/opengl/GLUtils.java
@@ -270,12 +270,10 @@ public final class GLUtils {
}
/**
* Enable tracing of OpenGL functions for this application.
* @hide
*/
- public static void enableTracing() {
- native_enableTracing();
- }
+ native public static void setTracingLevel(int level);
native private static void nativeClassInit();
@@ -285,5 +283,4 @@ public final class GLUtils {
Bitmap bitmap, int type, int border);
native private static int native_texSubImage2D(int target, int level, int xoffset, int yoffset,
Bitmap bitmap, int format, int type);
- native private static void native_enableTracing();
}
@@ -270,12 +270,10 @@ public final class GLUtils {
}
/**
- * Enable tracing of OpenGL functions for this application.
+ * Set OpenGL Tracing level for this application.
* @hide
*/